@@ -4,11 +4,12 @@ from urllib.parse import urlparse
 
 from dinao.backend.base import Connection, ConnectionPool, ResultSet
 from dinao.backend.errors import ConfigurationError, UnsupportedBackendError
+from dinao.backend.mariadb import ConnectionPoolMariaDB
 from dinao.backend.postgres import ConnectionPoolPSQLPsycopg2
 from dinao.backend.sqlite import ConnectionPoolSQLite3
 
 
-ENGINE_DEFAULTS = {"postgresql": "psycopg2", "sqlite3": None}
+ENGINE_DEFAULTS = {"postgresql": "psycopg2", "sqlite3": None, "mariadb": "mariadbconnector"}
 
 
 def create_connection_pool(db_url: str) -> ConnectionPool:
@@ -34,6 +35,8 @@ def create_connection_pool(db_url: str) -> ConnectionPool:
         return ConnectionPoolPSQLPsycopg2(db_url)
     if backend == "sqlite3" and engine is None:
         return ConnectionPoolSQLite3(db_url)
+    if backend == "mariadb" and engine == "mariadbconnector":
+        return ConnectionPoolMariaDB(db_url)
     raise UnsupportedBackendError(f"The backend+engine '{parsed_url.scheme}' is not supported")
 
 
